@@ -1,7 +1,7 @@
 package Bencher::Scenario::MojoDOM::Selection;
 
-our $DATE = '2016-04-12'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -63,7 +63,7 @@ Bencher::Scenario::MojoDOM::Selection - Benchmark selector
 
 =head1 VERSION
 
-This document describes version 0.003 of Bencher::Scenario::MojoDOM::Selection (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2016-04-12.
+This document describes version 0.004 of Bencher::Scenario::MojoDOM::Selection (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -73,6 +73,13 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Sample documents from C<PERLANCAR::HTML::Tree::Examples> are used.
+
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -103,25 +110,22 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m MojoDOM::Selection >>):
 
- +---------+----------------+-----------+-----------+------------+---------+---------+
- | dataset | arg_expr       | rate (/s) | time (ms) | vs_slowest | errors  | samples |
- +---------+----------------+-----------+-----------+------------+---------+---------+
- | medium1 | h4:first-child | 11.4      | 87.4      | 1          | 3e-05   | 20      |
- | medium1 | h4             | 15.1      | 66.2      | 1.32       | 2.1e-05 | 20      |
- | small1  | h4:first-child | 1.5e+04   | 0.065     | 1.4e+03    | 1e-07   | 35      |
- | small1  | h4             | 2e+04     | 0.05      | 1.75e+03   | 1.2e-08 | 24      |
- +---------+----------------+-----------+-----------+------------+---------+---------+
-
-=head1 DESCRIPTION
-
-Sample documents from C<PERLANCAR::HTML::Tree::Examples> are used.
+ #table1#
+ +---------+----------------+-----------+-----------+------------+-----------+---------+
+ | dataset | arg_expr       | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +---------+----------------+-----------+-----------+------------+-----------+---------+
+ | medium1 | h4:first-child |       8.5 |   120     |        1   |   0.00053 |      20 |
+ | medium1 | h4             |      11   |    94     |        1.2 |   0.00058 |      20 |
+ | small1  | h4:first-child |   12000   |     0.081 |     1500   | 1.1e-07   |      20 |
+ | small1  | h4             |   14000   |     0.07  |     1700   | 3.5e-07   |      20 |
+ +---------+----------------+-----------+-----------+------------+-----------+---------+
 
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -145,7 +149,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
